@@ -1,9 +1,9 @@
-package Pod::Coverage::Moose; # git description: v0.05-21-g230160c
+package Pod::Coverage::Moose; # git description: v0.06-2-g7fc3173
 # ABSTRACT: Pod::Coverage extension for Moose
 # KEYWORDS: pod coverage verification validity tests documentation completeness moose methods inheritance
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Moose;
 
@@ -173,7 +173,7 @@ Pod::Coverage::Moose - Pod::Coverage extension for Moose
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -260,6 +260,17 @@ L<Test::Pod::Coverage>
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Coverage-Moose>
+(or L<bug-Pod-Coverage-Moose@rt.cpan.org|mailto:bug-Pod-Coverage-Moose@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+http://lists.perl.org/list/moose.html.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#moose.
+
 =head1 AUTHOR
 
 Robert 'phaylon' Sedlacek <rs@474.at>
